@@ -5,13 +5,14 @@ const Lang = imports.lang;
 const Shell = imports.gi.Shell;
 const Signals = imports.signals;
 
-const FprintManagerIface = '<node> \
-<interface name="net.reactivated.Fprint.Manager"> \
-<method name="GetDefaultDevice"> \
-    <arg type="o" direction="out" /> \
-</method> \
-</interface> \
-</node>';
+const FprintManagerIface = `
+<node>
+<interface name="net.reactivated.Fprint.Manager">
+<method name="GetDefaultDevice">
+    <arg type="o" direction="out" />
+</method>
+</interface>
+</node>`;
 
 const FprintManagerInfo = Gio.DBusInterfaceInfo.new_for_xml(FprintManagerIface);
 
@@ -23,6 +24,12 @@ function FprintManager() {
                                    g_object_path: '/net/reactivated/Fprint/Manager',
                                    g_flags: (Gio.DBusProxyFlags.DO_NOT_LOAD_PROPERTIES) });
 
-    self.init(null);
+    try {
+        self.init(null);
+    } catch(e) {
+        log('Failed to connect to Fprint service: ' + e.message);
+        return null;
+    }
+
     return self;
 }
