@@ -5,61 +5,15 @@ const Lang = imports.lang;
 const Shell = imports.gi.Shell;
 const Signals = imports.signals;
 
-const ProviderIface = `
-<node>
-<interface name="org.freedesktop.realmd.Provider">
-    <property name="Name" type="s" access="read"/>
-    <property name="Version" type="s" access="read"/>
-    <property name="Realms" type="ao" access="read"/>
-    <method name="Discover">
-        <arg name="string" type="s" direction="in"/>
-        <arg name="options" type="a{sv}" direction="in"/>
-        <arg name="relevance" type="i" direction="out"/>
-        <arg name="realm" type="ao" direction="out"/>
-    </method>
-</interface>
-</node>`;
+const { loadInterfaceXML } = imports.misc.fileUtils;
+
+const ProviderIface = loadInterfaceXML("org.freedesktop.realmd.Provider");
 const Provider = Gio.DBusProxy.makeProxyWrapper(ProviderIface);
 
-const ServiceIface = `
-<node>
-<interface name="org.freedesktop.realmd.Service">
-    <method name="Cancel">
-        <arg name="operation" type="s" direction="in"/>
-    </method>
-    <method name="Release" />
-    <method name="SetLocale">
-        <arg name="locale" type="s" direction="in"/>
-    </method>
-    <signal name="Diagnostics">
-        <arg name="data" type="s"/>
-        <arg name="operation" type="s"/>
-    </signal>
-</interface>
-</node>`;
+const ServiceIface = loadInterfaceXML("org.freedesktop.realmd.Service");
 const Service = Gio.DBusProxy.makeProxyWrapper(ServiceIface);
 
-const RealmIface = `
-<node>
-<interface name="org.freedesktop.realmd.Realm">
-    <property name="Name" type="s" access="read"/>
-    <property name="Configured" type="s" access="read"/>
-    <property name="Details" type="a(ss)" access="read"/>
-    <property name="LoginFormats" type="as" access="read"/>
-    <property name="LoginPolicy" type="s" access="read"/>
-    <property name="PermittedLogins" type="as" access="read"/>
-    <property name="SupportedInterfaces" type="as" access="read"/>
-    <method name="ChangeLoginPolicy">
-        <arg name="login_policy" type="s" direction="in"/>
-        <arg name="permitted_add" type="as" direction="in"/>
-        <arg name="permitted_remove" type="as" direction="in"/>
-        <arg name="options" type="a{sv}" direction="in"/>
-    </method>
-    <method name="Deconfigure">
-        <arg name="options" type="a{sv}" direction="in"/>
-    </method>
-</interface>
-</node>`;
+const RealmIface = loadInterfaceXML("org.freedesktop.realmd.Realm");
 const Realm = Gio.DBusProxy.makeProxyWrapper(RealmIface);
 
 var Manager = new Lang.Class({
