@@ -119,6 +119,11 @@ var IBusManager = new Lang.Class({
                 let cursorLocation = { x, y, width: w, height: h };
                 this.emit('set-cursor-location', cursorLocation);
             });
+            this._panelService.connect('focus-in', (panel, path) => {
+                if (!GLib.str_has_suffix(path, '/InputContext_1'))
+                    this.emit ('focus-in');
+            });
+            this._panelService.connect('focus-out', () => { this.emit('focus-out'); });
 
             try {
                 // IBus versions older than 1.5.10 have a bug which
