@@ -42,35 +42,29 @@ function waitAndDraw(milliseconds) {
     let timeline = new Clutter.Timeline({ duration: milliseconds });
     timeline.start();
 
-    timeline.connect('new-frame',
-        function(timeline, frame) {
-            global.stage.queue_redraw();
-        });
+    timeline.connect('new-frame', (timeline, frame) => {
+        global.stage.queue_redraw();
+    });
 
-    timeline.connect('completed',
-        function() {
-            timeline.stop();
-            if (cb)
-                cb();
-        });
+    timeline.connect('completed', () => {
+        timeline.stop();
+        if (cb)
+            cb();
+    });
 
-    return function(callback) {
-        cb = callback;
-    };
+    return callback => { cb = callback; };
 }
 
 function waitSignal(object, signal) {
     let cb;
 
-    let id = object.connect(signal, function() {
+    let id = object.connect(signal, () => {
         object.disconnect(id);
         if (cb)
             cb();
     });
 
-    return function(callback) {
-        cb = callback;
-    };
+    return callback => { cb = callback; };
 }
 
 function extractBootTimestamp() {
@@ -142,8 +136,7 @@ function run() {
     global.frame_finish_timestamp = true;
 
     for (let k = 0; k < 5; k++)
-        yield Scripting.createTestWindow(640, 480,
-                                         { maximized: true });
+        yield Scripting.createTestWindow({ maximized: true });
     yield Scripting.waitTestWindows();
 
     yield Scripting.sleep(1000);
@@ -164,8 +157,7 @@ function run() {
     yield Scripting.destroyTestWindows();
     Main.overview.hide();
 
-    yield Scripting.createTestWindow(640, 480,
-                                     { maximized: true,
+    yield Scripting.createTestWindow({ maximized: true,
                                        redraws: true});
     yield Scripting.waitTestWindows();
 
@@ -270,7 +262,7 @@ function script_redrawTestDone(time) {
 function script_collectTimings(time) {
     for (let timing in redrawTimes) {
         let times = redrawTimes[timing];
-        times.sort(function(a, b) { return a - b });
+        times.sort((a, b) => a - b);
 
         let len = times.length;
         let median;
