@@ -12,6 +12,7 @@ const WebKit = imports.gi.WebKit2;
 const _ = Gettext.gettext;
 
 const Config = imports.misc.config;
+const { loadInterfaceXML } = imports.misc.fileUtils;
 
 const PortalHelperResult = {
     CANCELLED: 0,
@@ -30,26 +31,7 @@ const CONNECTIVITY_CHECK_HOST = 'nmcheck.gnome.org';
 const CONNECTIVITY_CHECK_URI = 'http://' + CONNECTIVITY_CHECK_HOST;
 const CONNECTIVITY_RECHECK_RATELIMIT_TIMEOUT = 30 * GLib.USEC_PER_SEC;
 
-const HelperDBusInterface = `
-<node>
-<interface name="org.gnome.Shell.PortalHelper">
-<method name="Authenticate">
-    <arg type="o" direction="in" name="connection" />
-    <arg type="s" direction="in" name="url" />
-    <arg type="u" direction="in" name="timestamp" />
-</method>
-<method name="Close">
-    <arg type="o" direction="in" name="connection" />
-</method>
-<method name="Refresh">
-    <arg type="o" direction="in" name="connection" />
-</method>
-<signal name="Done">
-    <arg type="o" name="connection" />
-    <arg type="u" name="result" />
-</signal>
-</interface>
-</node>`;
+const HelperDBusInterface = loadInterfaceXML('org.gnome.Shell.PortalHelper');
 
 var PortalHeaderBar = new Lang.Class({
     Name: 'PortalHeaderBar',
