@@ -19,7 +19,6 @@ const MagnifierDBus = imports.ui.magnifierDBus;
 const Params = imports.misc.params;
 const PointerWatcher = imports.ui.pointerWatcher;
 
-var MOUSE_POLL_FREQUENCY = 50;
 var CROSSHAIRS_CLIP_SIZE = [100, 100];
 var NO_CHANGE = 0.0;
 
@@ -62,7 +61,7 @@ var Magnifier = new Lang.Class({
         this._zoomRegions = [];
 
         // Create small clutter tree for the magnified mouse.
-        let cursorTracker = Meta.CursorTracker.get_for_screen(global.screen);
+        let cursorTracker = Meta.CursorTracker.get_for_display(global.display);
         this._mouseSprite = new Clutter.Texture();
         Shell.util_cursor_tracker_to_clutter(cursorTracker, this._mouseSprite);
         this._cursorRoot = new Clutter.Actor();
@@ -117,10 +116,10 @@ var Magnifier = new Lang.Class({
 
         if (isActive != activate) {
             if (activate) {
-                Meta.disable_unredirect_for_screen(global.screen);
+                Meta.disable_unredirect_for_display(global.display);
                 this.startTrackingMouse();
             } else {
-                Meta.enable_unredirect_for_screen(global.screen);
+                Meta.enable_unredirect_for_display(global.display);
                 this.stopTrackingMouse();
             }
         }
@@ -152,8 +151,10 @@ var Magnifier = new Lang.Class({
      * Turn on mouse tracking, if not already doing so.
      */
     startTrackingMouse() {
-        if (!this._pointerWatch)
-            this._pointerWatch = PointerWatcher.getPointerWatcher().addWatch(MOUSE_POLL_FREQUENCY, this.scrollToMousePos.bind(this));
+        if (!this._pointerWatch) {
+            let interval = 1000 / Clutter.get_default_frame_rate();
+            this._pointerWatch = PointerWatcher.getPointerWatcher().addWatch(interval, this.scrollToMousePos.bind(this));
+        }
     },
 
     /**
