@@ -395,10 +395,8 @@ var Overview = new Lang.Class({
         if (!Main.layoutManager.primaryMonitor)
             return;
 
-        let workArea = Main.layoutManager.getWorkAreaForMonitor(Main.layoutManager.primaryIndex);
-
-        this._coverPane.set_position(0, workArea.y);
-        this._coverPane.set_size(workArea.width, workArea.height);
+        this._coverPane.set_position(0, 0);
+        this._coverPane.set_size(global.screen_width, global.screen_height);
 
         this._updateBackgrounds();
     },
