@@ -7,55 +7,38 @@ const Lang = imports.lang;
 const St = imports.gi.St;
 const Signals = imports.signals;
 
+const BarLevel = imports.ui.barLevel;
+
 var SLIDER_SCROLL_STEP = 0.02; /* Slider scrolling step in % */
 
 var Slider = new Lang.Class({
     Name: "Slider",
+    Extends: BarLevel.BarLevel,
 
-    _init: function(value) {
-        if (isNaN(value))
-            // Avoid spreading NaNs around
-            throw TypeError('The slider value must be a number');
-        this._value = Math.max(Math.min(value, 1), 0);
-        this._sliderWidth = 0;
+    _init(value) {
+        let params = {
+            styleClass: 'slider',
+            canFocus: true,
+            reactive: true,
+            accessibleRole: Atk.Role.SLIDER,
+        }
+        this.parent(value, params)
 
-        this.actor = new St.DrawingArea({ style_class: 'slider',
-                                          can_focus: true,
-                                          reactive: true,
-                                          accessible_role: Atk.Role.SLIDER });
-        this.actor.connect('repaint', Lang.bind(this, this._sliderRepaint));
-        this.actor.connect('button-press-event', Lang.bind(this, this._startDragging));
-        this.actor.connect('touch-event', Lang.bind(this, this._touchDragging));
-        this.actor.connect('scroll-event', Lang.bind(this, this._onScrollEvent));
-        this.actor.connect('key-press-event', Lang.bind(this, this.onKeyPressEvent));
-        this.actor.connect('allocation-changed', (actor, box) => {
-            this._sliderWidth = box.get_width();
-        });
+        this.actor.connect('button-press-event', this._startDragging.bind(this));
+        this.actor.connect('touch-event', this._touchDragging.bind(this));
+        this.actor.connect('scroll-event', this._onScrollEvent.bind(this));
+        this.actor.connect('key-press-event', this.onKeyPressEvent.bind(this));
 
         this._releaseId = this._motionId = 0;
         this._dragging = false;
 
-        this._customAccessible = St.GenericAccessible.new_for_actor(this.actor);
-        this.actor.set_accessible(this._customAccessible);
-
-        this._customAccessible.connect('get-current-value', Lang.bind(this, this._getCurrentValue));
-        this._customAccessible.connect('get-minimum-value', Lang.bind(this, this._getMinimumValue));
-        this._customAccessible.connect('get-maximum-value', Lang.bind(this, this._getMaximumValue));
-        this._customAccessible.connect('get-minimum-increment', Lang.bind(this, this._getMinimumIncrement));
-        this._customAccessible.connect('set-current-value', Lang.bind(this, this._setCurrentValue));
-
-        this.connect('value-changed', Lang.bind(this, this._valueChanged));
+        this._customAccessible.connect('get-minimum-increment', this._getMinimumIncrement.bind(this));
     },
 
-    setValue: function(value) {
-        if (isNaN(value))
-            throw TypeError('The slider value must be a number');
+    _barLevelRepaint(area) {
+        this.parent(area);
 
-        this._value = Math.max(Math.min(value, 1), 0);
-        this.actor.queue_repaint();
-    },
-
-    _sliderRepaint: function(area) {
+        // Add handle
         let cr = area.get_context();
         let themeNode = area.get_theme_node();
         let [width, height] = area.get_surface_size();
@@ -66,41 +49,9 @@ var Slider = new Lang.Class({
         let [hasHandleColor, handleBorderColor] =
             themeNode.lookup_color('-slider-handle-border-color', false);
 
-        let sliderHeight = themeNode.get_length('-slider-height');
-
-        let sliderBorderWidth = themeNode.get_length('-slider-border-width');
-        let sliderBorderRadius = Math.min(width, sliderHeight) / 2;
-
-        let sliderBorderColor = themeNode.get_color('-slider-border-color');
-        let sliderColor = themeNode.get_color('-slider-background-color');
-
-        let sliderActiveBorderColor = themeNode.get_color('-slider-active-border-color');
-        let sliderActiveColor = themeNode.get_color('-slider-active-background-color');
-
         const TAU = Math.PI * 2;
 
-        let handleX = handleRadius + (width - 2 * handleRadius) * this._value;
-
-        cr.arc(sliderBorderRadius + sliderBorderWidth, height / 2, sliderBorderRadius, TAU * 1/4, TAU * 3/4);
-        cr.lineTo(handleX, (height - sliderHeight) / 2);
-        cr.lineTo(handleX, (height + sliderHeight) / 2);
-        cr.lineTo(sliderBorderRadius + sliderBorderWidth, (height + sliderHeight) / 2);
-        Clutter.cairo_set_source_color(cr, sliderActiveColor);
-        cr.fillPreserve();
-        Clutter.cairo_set_source_color(cr, sliderActiveBorderColor);
-        cr.setLineWidth(sliderBorderWidth);
-        cr.stroke();
-
-        cr.arc(width - sliderBorderRadius - sliderBorderWidth, height / 2, sliderBorderRadius, TAU * 3/4, TAU * 1/4);
-        cr.lineTo(handleX, (height + sliderHeight) / 2);
-        cr.lineTo(handleX, (height - sliderHeight) / 2);
-        cr.lineTo(width - sliderBorderRadius - sliderBorderWidth, (height - sliderHeight) / 2);
-        Clutter.cairo_set_source_color(cr, sliderColor);
-        cr.fillPreserve();
-        Clutter.cairo_set_source_color(cr, sliderBorderColor);
-        cr.setLineWidth(sliderBorderWidth);
-        cr.stroke();
-
+        let handleX = handleRadius + (width - 2 * handleRadius) * this._value / this._maxValue;
         let handleY = height / 2;
 
         let color = themeNode.get_foreground_color();
@@ -115,11 +66,11 @@ var Slider = new Lang.Class({
         cr.$dispose();
     },
 
-    _startDragging: function(actor, event) {
+    _startDragging(actor, event) {
         return this.startDragging(event);
     },
 
-    startDragging: function(event) {
+    startDragging(event) {
         if (this._dragging)
             return Clutter.EVENT_PROPAGATE;
 
@@ -137,8 +88,8 @@ var Slider = new Lang.Class({
         this._grabbedSequence = sequence;
 
         if (sequence == null) {
-            this._releaseId = this.actor.connect('button-release-event', Lang.bind(this, this._endDragging));
-            this._motionId = this.actor.connect('motion-event', Lang.bind(this, this._motionEvent));
+            this._releaseId = this.actor.connect('button-release-event', this._endDragging.bind(this));
+            this._motionId = this.actor.connect('motion-event', this._motionEvent.bind(this));
         }
 
         // We need to emit 'drag-begin' before moving the handle to make
@@ -151,7 +102,7 @@ var Slider = new Lang.Class({
         return Clutter.EVENT_STOP;
     },
 
-    _endDragging: function() {
+    _endDragging() {
         if (this._dragging) {
             if (this._releaseId)
                 this.actor.disconnect(this._releaseId);
@@ -172,7 +123,7 @@ var Slider = new Lang.Class({
         return Clutter.EVENT_STOP;
     },
 
-    _touchDragging: function(actor, event) {
+    _touchDragging(actor, event) {
         let device = event.get_device();
         let sequence = event.get_event_sequence();
 
@@ -190,7 +141,7 @@ var Slider = new Lang.Class({
         return Clutter.EVENT_PROPAGATE;
     },
 
-    scroll: function(event) {
+    scroll(event) {
         let direction = event.get_scroll_direction();
         let delta;
 
@@ -208,29 +159,29 @@ var Slider = new Lang.Class({
             delta = -dy * SLIDER_SCROLL_STEP;
         }
 
-        this._value = Math.min(Math.max(0, this._value + delta), 1);
+        this._value = Math.min(Math.max(0, this._value + delta), this._maxValue);
 
         this.actor.queue_repaint();
         this.emit('value-changed', this._value);
         return Clutter.EVENT_STOP;
     },
 
-    _onScrollEvent: function(actor, event) {
+    _onScrollEvent(actor, event) {
         return this.scroll(event);
     },
 
-    _motionEvent: function(actor, event) {
+    _motionEvent(actor, event) {
         let absX, absY;
         [absX, absY] = event.get_coords();
         this._moveHandle(absX, absY);
         return Clutter.EVENT_STOP;
     },
 
-    onKeyPressEvent: function (actor, event) {
+    onKeyPressEvent(actor, event) {
         let key = event.get_key_symbol();
         if (key == Clutter.KEY_Right || key == Clutter.KEY_Left) {
             let delta = key == Clutter.KEY_Right ? 0.1 : -0.1;
-            this._value = Math.max(0, Math.min(this._value + delta, 1));
+            this._value = Math.max(0, Math.min(this._value + delta, this._maxValue));
             this.actor.queue_repaint();
             this.emit('drag-begin');
             this.emit('value-changed', this._value);
@@ -240,13 +191,13 @@ var Slider = new Lang.Class({
         return Clutter.EVENT_PROPAGATE;
     },
 
-    _moveHandle: function(absX, absY) {
+    _moveHandle(absX, absY) {
         let relX, relY, sliderX, sliderY;
         [sliderX, sliderY] = this.actor.get_transformed_position();
         relX = absX - sliderX;
         relY = absY - sliderY;
 
-        let width = this._sliderWidth;
+        let width = this._barLevelWidth;
         let handleRadius = this.actor.get_theme_node().get_length('-slider-handle-radius');
 
         let newvalue;
@@ -256,38 +207,14 @@ var Slider = new Lang.Class({
             newvalue = 1;
         else
             newvalue = (relX - handleRadius) / (width - 2 * handleRadius);
-        this._value = newvalue;
+        this._value = newvalue * this._maxValue;
         this.actor.queue_repaint();
         this.emit('value-changed', this._value);
     },
 
-    _getCurrentValue: function (actor) {
-        return this._value;
-    },
-
-    _getMinimumValue: function (actor) {
-        return 0;
-    },
-
-    _getMaximumValue: function (actor) {
-        return 1;
-    },
-
-    _getMinimumIncrement: function (actor) {
+    _getMinimumIncrement(actor) {
         return 0.1;
     },
-
-    _setCurrentValue: function (actor, value) {
-        this._value = value;
-    },
-
-    _valueChanged: function (slider, value, property) {
-        this._customAccessible.notify ("accessible-value");
-    },
-
-    get value() {
-        return this._value;
-    }
 });
 
 Signals.addSignalMethods(Slider.prototype);
