@@ -360,14 +360,11 @@ var InputSourceManager = new Lang.Class({
         this._settings.connect('per-window-changed', this._sourcesPerWindowChanged.bind(this));
         this._sourcesPerWindowChanged();
         this._disableIBus = false;
-        this._reloading = false;
     },
 
     reload() {
-        this._reloading = true;
         this._keyboardManager.setKeyboardOptions(this._settings.keyboardOptions);
         this._inputSourcesChanged();
-        this._reloading = false;
     },
 
     _ibusReadyCallback(im, ready) {
@@ -401,7 +398,7 @@ var InputSourceManager = new Lang.Class({
         return true;
     },
 
-    _switchInputSource(display, screen, window, binding) {
+    _switchInputSource(display, window, binding) {
         if (this._mruSources.length < 2)
             return;
 
@@ -461,15 +458,7 @@ var InputSourceManager = new Lang.Class({
     },
 
     activateInputSource(is, interactive) {
-        // The focus changes during holdKeyboard/releaseKeyboard may trick
-        // the client into hiding UI containing the currently focused entry.
-        // So holdKeyboard/releaseKeyboard are not called when
-        // 'set-content-type' signal is received.
-        // E.g. Focusing on a password entry in a popup in Xorg Firefox
-        // will emit 'set-content-type' signal.
-        // https://gitlab.gnome.org/GNOME/gnome-shell/issues/391
-        if (!this._reloading)
-            KeyboardManager.holdKeyboard();
+        KeyboardManager.holdKeyboard();
         this._keyboardManager.apply(is.xkbId);
 
         // All the "xkb:..." IBus engines simply "echo" back symbols,
@@ -484,10 +473,7 @@ var InputSourceManager = new Lang.Class({
         else
             engine = 'xkb:us::eng';
 
-        if (!this._reloading)
-            this._ibusManager.setEngine(engine, KeyboardManager.releaseKeyboard);
-        else
-            this._ibusManager.setEngine(engine);
+        this._ibusManager.setEngine(engine, KeyboardManager.releaseKeyboard);
         this._currentInputSourceChanged(is);
 
         if (interactive)
