@@ -10,22 +10,12 @@ const Main = imports.ui.main;
 const PanelMenu = imports.ui.panelMenu;
 const PopupMenu = imports.ui.popupMenu;
 
+const { loadInterfaceXML } = imports.misc.fileUtils;
+
 const BUS_NAME = 'org.freedesktop.UPower';
 const OBJECT_PATH = '/org/freedesktop/UPower/devices/DisplayDevice';
 
-const DisplayDeviceInterface = `
-<node>
-<interface name="org.freedesktop.UPower.Device">
-  <property name="Type" type="u" access="read"/>
-  <property name="State" type="u" access="read"/>
-  <property name="Percentage" type="d" access="read"/>
-  <property name="TimeToEmpty" type="x" access="read"/>
-  <property name="TimeToFull" type="x" access="read"/>
-  <property name="IsPresent" type="b" access="read"/>
-  <property name="IconName" type="s" access="read"/>
-</interface>
-</node>`;
-
+const DisplayDeviceInterface = loadInterfaceXML('org.freedesktop.UPower.Device');
 const PowerManagerProxy = Gio.DBusProxy.makeProxyWrapper(DisplayDeviceInterface);
 
 const SHOW_BATTERY_PERCENTAGE       = 'show-battery-percentage';
