@@ -49,7 +49,7 @@ function _wrapTweening(target, tweeningParameters) {
             state.destroyedId = target.connect('destroy', _actorDestroyed);
         } else if (target.actor && target.actor instanceof Clutter.Actor) {
             state.actor = target.actor;
-            state.destroyedId = target.actor.connect('destroy', function() { _actorDestroyed(target); });
+            state.destroyedId = target.actor.connect('destroy', () => { _actorDestroyed(target); });
         }
     }
 
@@ -87,12 +87,12 @@ function _addHandler(target, params, name, handler) {
         let oldParams = params[name + 'Params'];
         let eventScope = oldScope ? oldScope : target;
 
-        params[name] = function () {
+        params[name] = () => {
             oldHandler.apply(eventScope, oldParams);
             handler(target);
         };
     } else
-        params[name] = function () { handler(target); };
+        params[name] = () => { handler(target); };
 }
 
 function _actorDestroyed(target) {
@@ -167,7 +167,7 @@ var ClutterFrameTicker = new Lang.Class({
 
     FRAME_RATE : 60,
 
-    _init : function() {
+    _init() {
         // We don't have a finite duration; tweener will tell us to stop
         // when we need to stop, so use 1000 seconds as "infinity", and
         // set the timeline to loop. Doing this means we have to track
@@ -178,10 +178,9 @@ var ClutterFrameTicker = new Lang.Class({
         this._startTime = -1;
         this._currentTime = -1;
 
-        this._timeline.connect('new-frame', Lang.bind(this,
-            function(timeline, frame) {
-                this._onNewFrame(frame);
-            }));
+        this._timeline.connect('new-frame', (timeline, frame) => {
+            this._onNewFrame(frame);
+        });
 
         let perf_log = Shell.PerfLog.get_default();
         perf_log.define_event("tweener.framePrepareStart",
@@ -192,7 +191,7 @@ var ClutterFrameTicker = new Lang.Class({
                               "");
     },
 
-    _onNewFrame : function(frame) {
+    _onNewFrame(frame) {
         // If there is a lot of setup to start the animation, then
         // first frame number we get from clutter might be a long ways
         // into the animation (or the animation might even be done).
@@ -209,18 +208,18 @@ var ClutterFrameTicker = new Lang.Class({
         perf_log.event("tweener.framePrepareDone");
     },
 
-    getTime : function() {
+    getTime() {
         return this._currentTime;
     },
 
-    start : function() {
+    start() {
         if (St.get_slow_down_factor() > 0)
             Tweener.setTimeScale(1 / St.get_slow_down_factor());
         this._timeline.start();
         global.begin_work();
     },
 
-    stop : function() {
+    stop() {
         this._timeline.stop();
         this._startTime = -1;
         this._currentTime = -1;
