@@ -91,6 +91,9 @@ static const MetaPluginInfo *gnome_shell_plugin_plugin_info   (MetaPlugin *plugi
 static MetaCloseDialog * gnome_shell_plugin_create_close_dialog (MetaPlugin *plugin,
                                                               MetaWindow *window);
 
+static MetaInhibitShortcutsDialog * gnome_shell_plugin_create_inhibit_shortcuts_dialog (MetaPlugin *plugin,
+                                                                                        MetaWindow *window);
+
 #define GNOME_TYPE_SHELL_PLUGIN            (gnome_shell_plugin_get_type ())
 #define GNOME_SHELL_PLUGIN(obj)            (G_TYPE_CHECK_INSTANCE_CAST ((obj), GNOME_TYPE_SHELL_PLUGIN, GnomeShellPlugin))
 #define GNOME_SHELL_PLUGIN_CLASS(klass)    (G_TYPE_CHECK_CLASS_CAST ((klass),  GNOME_TYPE_SHELL_PLUGIN, GnomeShellPluginClass))
@@ -153,6 +156,7 @@ gnome_shell_plugin_class_init (GnomeShellPluginClass *klass)
   plugin_class->plugin_info       = gnome_shell_plugin_plugin_info;
 
   plugin_class->create_close_dialog = gnome_shell_plugin_create_close_dialog;
+  plugin_class->create_inhibit_shortcuts_dialog = gnome_shell_plugin_create_inhibit_shortcuts_dialog;
 }
 
 static void
@@ -163,22 +167,19 @@ gnome_shell_plugin_init (GnomeShellPlugin *shell_plugin)
 static gboolean
 gnome_shell_plugin_has_swap_event (GnomeShellPlugin *shell_plugin)
 {
-  MetaPlugin *plugin = META_PLUGIN (shell_plugin);
   CoglDisplay *cogl_display =
     cogl_context_get_display (shell_plugin->cogl_context);
   CoglRenderer *renderer = cogl_display_get_renderer (cogl_display);
   const char * (* query_extensions_string) (Display *dpy, int screen);
   Bool (* query_extension) (Display *dpy, int *error, int *event);
-  MetaScreen *screen;
   Display *xdisplay;
+  int screen_number;
   const char *glx_extensions;
 
   /* We will only get swap events if Cogl is using GLX */
   if (cogl_renderer_get_winsys_id (renderer) != COGL_WINSYS_ID_GLX)
     return FALSE;
 
-  screen = meta_plugin_get_screen (plugin);
-
   xdisplay = clutter_x11_get_default_display ();
 
   query_extensions_string =
@@ -190,9 +191,8 @@ gnome_shell_plugin_has_swap_event (GnomeShellPlugin *shell_plugin)
                    &shell_plugin->glx_error_base,
                    &shell_plugin->glx_event_base);
 
-  glx_extensions =
-    query_extensions_string (xdisplay,
-                             meta_screen_get_screen_number (screen));
+  screen_number = XDefaultScreen (xdisplay);
+  glx_extensions = query_extensions_string (xdisplay, screen_number);
 
   return strstr (glx_extensions, "GLX_INTEL_swap_event") != NULL;
 }
@@ -436,3 +436,10 @@ gnome_shell_plugin_create_close_dialog (MetaPlugin *plugin,
 {
   return _shell_wm_create_close_dialog (get_shell_wm (), window);
 }
+
+static MetaInhibitShortcutsDialog *
+gnome_shell_plugin_create_inhibit_shortcuts_dialog (MetaPlugin *plugin,
+                                                    MetaWindow *window)
+{
+  return _shell_wm_create_inhibit_shortcuts_dialog (get_shell_wm (), window);
+}
