@@ -1199,7 +1199,7 @@ shell_app_request_quit (ShellApp   *app)
     {
       MetaWindow *win = iter->data;
 
-      if (meta_window_is_skip_taskbar (win))
+      if (!meta_window_can_close (win))
         continue;
 
       meta_window_delete (win, shell_global_get_current_time (shell_global_get ()));
