@@ -59,6 +59,24 @@ assert_font (StThemeNode *node,
   g_free (value);
 }
 
+static void
+assert_font_features (StThemeNode *node,
+                      const char  *node_description,
+                      const char  *expected)
+{
+  char *value = st_theme_node_get_font_features (node);
+
+  if (g_strcmp0 (expected, value) != 0)
+    {
+      g_print ("%s: %s.font-feature-settings: expected: %s, got: %s\n",
+               test, node_description, expected, value);
+      fail = TRUE;
+    }
+
+  if (value)
+    g_free (value);
+}
+
 static char *
 text_decoration_to_string (StTextDecoration decoration)
 {
@@ -396,7 +414,7 @@ test_background (void)
   /* text1 inherits the background image but not the color */
   assert_background_color (text1,  "text1",  0x00000000);
   assert_background_image (text1,  "text1",  "st/some-background.png");
-  /* text1 inherits inherits both, but then background: none overrides both */
+  /* text2 inherits both, but then background: none overrides both */
   assert_background_color (text2,  "text2",  0x00000000);
   assert_background_image (text2,  "text2",  NULL);
   /* background-image property */
@@ -413,6 +431,22 @@ test_font (void)
   assert_font (text3,  "text3",  "serif Bold Oblique Small-Caps 24px");
 }
 
+static void
+test_font_features (void)
+{
+  test = "font_features";
+  /* group1 has font-feature-settings: "tnum" */
+  assert_font_features (group1, "group1", "\"tnum\"");
+  /* text2 should inherit from group1 */
+  assert_font_features (text2,  "text2", "\"tnum\"");
+  /* group2 has font-feature-settings: "tnum", "zero" */
+  assert_font_features (group2, "group2", "\"tnum\", \"zero\"");
+  /* text3 should inherit from group2 using the inherit keyword */
+  assert_font_features (text3,  "text3",  "\"tnum\", \"zero\"");
+  /* text4 has font-feature-settings: normal */
+  assert_font_features (text4,  "text4",  NULL);
+}
+
 static void
 test_pseudo_class (void)
 {
@@ -554,6 +588,7 @@ main (int argc, char **argv)
   test_border ();
   test_background ();
   test_font ();
+  test_font_features ();
   test_pseudo_class ();
   test_inline_style ();
 
